@@ -1,5 +1,5 @@
 #  diceware -- passphrases to remember
-#  Copyright (C) 2015, 2016  Uli Fouquet and contributors.
+#  Copyright (C) 2015-2017  Uli Fouquet and contributors.
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 """
 import os
 import re
+import sys
 import tempfile
 
 #: Maximum in-memory file size in bytes (20 MB).
@@ -26,10 +27,6 @@ import tempfile
 #: disk.
 MAX_IN_MEM_SIZE = 20 * 1024 * 1024
 
-#: The directory in which wordlists are stored
-WORDLISTS_DIR = os.path.abspath(
-    os.path.join(os.path.dirname(__file__), 'wordlists'))
-
 #: A regular expression matching allowed wordlist names. We
 #: allow names that cannot easily mess up filesystems.
 RE_WORDLIST_NAME = re.compile('^[\w-]+$')
@@ -42,13 +39,21 @@ RE_VALID_WORDLIST_FILENAME = re.compile(
     '^wordlist_([\w-]+)\.[\w][\w\.]+[\w]+$')
 
 
+def get_wordlists_dir():
+    """Get the directory in which wordlsts are stored.
+    """
+    return os.path.abspath(
+        os.path.join(os.path.dirname(__file__), 'wordlists'))
+
+
 def get_wordlist_names():
     """Get a all names of wordlists stored locally.
     """
     result = []
-    filenames = os.listdir(WORDLISTS_DIR)
+    wordlists_dir = get_wordlists_dir()
+    filenames = os.listdir(wordlists_dir)
     for filename in filenames:
-        if not os.path.isfile(os.path.join(WORDLISTS_DIR, filename)):
+        if not os.path.isfile(os.path.join(wordlists_dir, filename)):
             continue
         match = RE_VALID_WORDLIST_FILENAME.match(filename)
         if not match:
@@ -69,62 +74,57 @@ def get_wordlist_path(name):
     """
     if not RE_WORDLIST_NAME.match(name):
         raise ValueError("Not a valid wordlist name: %s" % name)
-    for filename in os.listdir(WORDLISTS_DIR):
-        if not os.path.isfile(os.path.join(WORDLISTS_DIR, filename)):
+    wordlists_dir = get_wordlists_dir()
+    for filename in os.listdir(wordlists_dir):
+        if not os.path.isfile(os.path.join(wordlists_dir, filename)):
             continue
         match = RE_VALID_WORDLIST_FILENAME.match(filename)
         if match and match.groups()[0] == name:
-            return os.path.join(WORDLISTS_DIR, filename)
+            return os.path.join(wordlists_dir, filename)
 
 
 class WordList(object):
     """A word list contains words for building passphrases.
 
-    `path_or_filelike` is the path of the wordlist file or an already
-    opened file. Opened files must be open for reading, of course. We
-    expect filelike objects to support at least `read()`.
+    `path` is the path of the wordlist file. With single dash (``-``) as path,
+    we read from `sys.stdin`.
 
-    If a file-like object does not support `seek()` (like `sys.stdin`),
-    we create a temporary, seekable copy of the input stream. The copy
-    is written to disk only, if it is larger than
-    `MAX_IN_MEM_SIZE`. Otherwise the wordlist is kept in memory.
+    In case input comes from stdin, we write the input stream into a file if
+    the content length is larger than `MAX_IN_MEM_SIZE`. Otherwise, the
+    wordlist is kept in memory.
 
-    Please note that open file descriptors are not closed after reading.
+    Wordlist files are expected to contain words, one word per line. Empty
+    lines are ignored, also whitespaces before or trailing a line are
+    stripped. If a "word" contains inner whitespaces, then these are
+    preserved.
 
-    Wordlist files are expected to contain words, one word per
-    line. Empty lines are ignored, also whitespaces before or trailing
-    a line are stripped. If a "word" contains inner whitespaces, then
-    these are preserved.
+    The input file can be a signed wordlist. Signed wordlists are expected to
+    be ordinary lists of words but with ASCII armored signatures (as described
+    in RFC 4880).
 
-    The input file can be a signed wordlist. Signed wordlists are
-    expected to be ordinary lists of words but with ASCII armored
-    signatures (as described in RFC 4880).
+    In case of signed wordlists the signature headers/footers are stripped and
+    the contained list of words is read.
 
-    In case of signed wordlists the signature headers/footers are
-    stripped and the contained list of words is read.
-
-    WordList are generators. That means, that you can retrieve the
-    words of a wordlist by iterating over an instance of `WordList`.
+    WordList are generators. That means, that you can retrieve the words of a
+    wordlist by iterating over an instance of `WordList`.
 
     """
-    def __init__(self, path_or_filelike=None):
-        self.path = None
-        if not hasattr(path_or_filelike, 'read'):
-            # got a path, not a filelike object
-            self.path = path_or_filelike
-            self.fd = open(self.path, "r")
-        else:
-            self.fd = path_or_filelike
-            try:
-                self.fd.seek(0)
-            except IOError:
-                # the given filelike does not support seek(). Create an own.
-                self.fd = tempfile.SpooledTemporaryFile(
+    def __init__(self, path):
+        self.path = path
+        self.fd = None
+        if self.path == "-":
+            self.fd = tempfile.SpooledTemporaryFile(
                     max_size=MAX_IN_MEM_SIZE, mode="w+")
-                self.fd.write(path_or_filelike.read())
-                self.fd.seek(0)
+            self.fd.write(sys.stdin.read())
+            self.fd.seek(0)
+        else:
+            self.fd = open(self.path, "r")
         self.signed = self.is_signed()
 
+    def __del__(self):
+        if self.path != "-" and self.fd is not None:
+            self.fd.close()
+
     def __iter__(self):
         self.fd.seek(0)
         if self.signed:
