@@ -5,8 +5,9 @@ import pytest
 import re
 import sys
 from io import StringIO
+from errno import EISDIR
 from diceware import (
-    WORDLISTS_DIR, SPECIAL_CHARS, insert_special_char, get_passphrase,
+    get_wordlists_dir, SPECIAL_CHARS, insert_special_char, get_passphrase,
     handle_options, main, __version__, print_version, get_random_sources,
     get_wordlist_names
     )
@@ -42,7 +43,7 @@ class TestHandleOptions(object):
         assert options.version is False
         assert options.delimiter == ""
         assert options.randomsource == "system"
-        assert options.wordlist == "en_securedrop"
+        assert options.wordlist == "en_eff"
         assert options.verbose == 0
 
     def test_handle_options_infile(self, tmpdir):
@@ -51,8 +52,7 @@ class TestHandleOptions(object):
         with open('mywords', 'w') as fd:
             fd.write('one\ntwo\n')
         options = handle_options(['mywords', ])
-        assert options.infile is not None
-        assert options.infile.read() == 'one\ntwo\n'
+        assert options.infile == 'mywords'
 
     def test_handle_options_version(self):
         # we can ask for version infos
@@ -244,13 +244,6 @@ class TestDicewareModule(object):
         phrase = get_passphrase(options)
         assert " " in phrase
 
-    def test_get_passphrase_wordlist_fd(self):
-        #  we can pass in an own wordlist
-        options = handle_options(args=[])
-        options.infile = StringIO("word1\n")
-        phrase = get_passphrase(options)
-        assert "Word1" in phrase
-
     def test_print_version(self, capsys):
         # we can print version infos
         print_version()
@@ -258,10 +251,11 @@ class TestDicewareModule(object):
         assert err == ''
         assert __version__ in out
 
+    @pytest.mark.packaging
     def test_print_version_current_year(self, capsys):
         # in version infos we display the current year
         print_version()
-        pattern = ".*\(C\) (20[0-9]{2}, )*%s.*" % (
+        pattern = ".*\(C\) (20[0-9]{2}([,\-] ?))*%s.*" % (
             datetime.datetime.now().year)
         out, err = capsys.readouterr()
         assert re.match(pattern, out, re.M + re.S) is not None
@@ -286,8 +280,10 @@ class TestDicewareModule(object):
             os.path.dirname(__file__), 'exp_help_output.txt')
         with open(expected_path, 'r') as fd:
             expected_output = fd.read()
-        out = out.replace(WORDLISTS_DIR, "<WORDLISTS-DIR>")
-        out = out.replace("\n<WORDLISTS-DIR>", " <WORDLISTS-DIR>")
+        wordlists_dir = get_wordlists_dir()
+        expected_output = expected_output.replace("\n", "")
+        out = expected_output.replace("\n", "")
+        out = out.replace(wordlists_dir, "<WORDLISTS-DIR>")
         assert out == expected_output
 
     def test_main_version(self, argv_handler, capsys):
@@ -323,6 +319,25 @@ class TestDicewareModule(object):
         out, err = capsys.readouterr()
         assert out == 'Word1Word1\n'
 
+    def test_main_infile_nonexisting(self, argv_handler, capsys):
+        # main() prints error if file does not exist
+        # raises the exception if it's other that file not exist
+        sys.argv = ['diceware', 'nonexisting']
+        with pytest.raises(SystemExit) as exc_info:
+            main()
+        assert exc_info.value.code == 1
+        out, err = capsys.readouterr()
+        assert "The file 'nonexisting' does not exist." in err
+
+    def test_main_infile_not_a_file(self, argv_handler, tmpdir):
+        # give directory as input
+        tmpdir.mkdir("wordlist")
+        tmpdir.chdir()
+        sys.argv = ['diceware', 'wordlist']
+        with pytest.raises(IOError) as infile_error:
+            main()
+        assert infile_error.value.errno == EISDIR
+
     def test_main_delimiters(self, argv_handler, capsys):
         # delimiters are respected on calls to main
         sys.stdin = StringIO("word1\n")
